// -*-Mode: C++;-*- 

/*
 * $Id: deltabledlg.h,v 2.7 2001/04/16 13:01:09 ral Exp $
 * Include file for delete table dlg
 */

#ifndef CDeleteTableDlg_included
#define CDeleteTableDlg_included

#include "deltabledata.h"
#include "stringlist.h"
#include "smart_pointer.h"

class CMySql;

class CDeleteTableDlg : public CDeleteTableDlgData
{
    Q_OBJECT
public:
    CDeleteTableDlg(smart_pointer<CMySql>& _sql_server,QWidget* parent = NULL,const char* name = NULL);
    virtual ~CDeleteTableDlg();

protected:
    stringlist db_list;
    smart_pointer<CMySql> sql_server;

protected slots:
    void HilightDB(int);
    void DelTable();
    void TableHilight(int);
    const char*get_error_head();
};
#endif // CDeleteTableDlg_included
